==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/CustomizablePage.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CustomizablePage
 */
@JsonPropertyOrder({ CustomizablePage.JSON_PROPERTY_PAGE_CONTENT })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class CustomizablePage implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PAGE_CONTENT = "pageContent";
    private String pageContent;

    public CustomizablePage() {
    }

    public CustomizablePage pageContent(String pageContent) {

        this.pageContent = pageContent;
        return this;
    }

    /**
     * The HTML for the page
     *
     * @return pageContent
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The HTML for the page")
    @JsonProperty(JSON_PROPERTY_PAGE_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPageContent() {
        return pageContent;
    }

    @JsonProperty(JSON_PROPERTY_PAGE_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPageContent(String pageContent) {
        this.pageContent = pageContent;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CustomizablePage customizablePage = (CustomizablePage) o;
        return Objects.equals(this.pageContent, customizablePage.pageContent);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(pageContent);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CustomizablePage {\n");
        sb.append("    pageContent: ").append(toIndentedString(pageContent)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/CustomizablePage.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CustomizablePage
 */
@JsonPropertyOrder({ CustomizablePage.JSON_PROPERTY_PAGE_CONTENT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class CustomizablePage implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_PAGE_CONTENT = "pageContent";
    private String pageContent;

    public CustomizablePage() {
    }

    public CustomizablePage pageContent(String pageContent) {

        this.pageContent = pageContent;
        return this;
    }

    /**
     * The HTML for the page
     *
     * @return pageContent
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The HTML for the page")
    @JsonProperty(JSON_PROPERTY_PAGE_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getPageContent() {
        return pageContent;
    }

    @JsonProperty(JSON_PROPERTY_PAGE_CONTENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPageContent(String pageContent) {
        this.pageContent = pageContent;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CustomizablePage customizablePage = (CustomizablePage) o;
        return Objects.equals(this.pageContent, customizablePage.pageContent);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(pageContent);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CustomizablePage {\n");
        sb.append("    pageContent: ").append(toIndentedString(pageContent)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
